"""Unit Tests for the socialprofile module forms"""

# pylint: disable=R0904, C0103

#from django.test import TestCase

#from django.core.exceptions import ObjectDoesNotExist
#from socialprofile.models import SocialProfile
#from social.apps.django_app.default.models import UserSocialAuth
#from socialprofile.forms import SocialProfileForm
#from django.forms.models import model_to_dict
#import logging

#LOGGER = logging.getLogger(name='socialprofile.test_forms')


#class SocialProfileFormTestCase(TestCase):
    #"""Test Case for Social Profile Forms"""

    #def setUp(self):
        #"""Set up common assets for tests"""
        #LOGGER.debug("SocialProfileForm Tests setUp")
        #self.user1 = SocialProfile.objects.create_user('user1', 'user1@user1.com', 'user1password')
        #self.user1.gender = 'other'
        #self.user1.url = 'http://test.com'
        #self.user1.description = 'Test User 1'
        #self.user1.image_url = 'http://www.gravatar.com/avatar/00000000000000000000000000000000?d=mm'
        #self.user1.save()
        # self.sa1 = UserSocialAuth.objects.create(user=self.user1, provider='google-oauth2', uid='user1@user1.com')

    #def test_socialprofile_form_view(self):
        #"""Test editing user profile data through form in isolation"""
        #LOGGER.debug("Test socialprofile edit form")
        #form = SocialProfileForm(instance=self.user1)
        #form_html = form.as_p()
        #LOGGER.debug(form_html)
        #self.assertInHTML('<option value="other" selected="selected">Other</option>', form_html)
        #self.assertInHTML('<input id="id_returnTo" name="returnTo" type="hidden" value="/" />', form_html)
        #self.assertInHTML('<textarea cols="40" id="id_description" name="description" rows="10">Test User 1</textarea>', form_html)
        #self.assertInHTML('<input id="id_image_url" maxlength="500" name="image_url" type="url" value="http://www.gravatar.com/avatar/00000000000000000000000000000000?d=mm" />', form_html)
        #self.assertInHTML('<input id="id_manually_edited" name="manually_edited" type="hidden" value="True" />', form_html)
        #self.assertInHTML('<input id="id_url" maxlength="500" name="url" type="url" value="http://test.com" />', form_html)

    #def test_socialprofile_form_update(self):
        #"""Test Form Update"""
        #LOGGER.debug("Test socialprofile edit form")
        #data = model_to_dict(self.user1)
        #data['description'] = 'new description'
        #data['gender'] = 'female'
        #data['url'] = 'http://new.url'
        #data['image_url'] = 'http://new.image.url'
        #form = SocialProfileForm(data=data, instance=self.user1)
        #self.assertTrue(form.is_valid())
        #form.save()
        #self.assertEquals(self.user1.description, 'new description')
        #self.assertEquals(self.user1.url, 'http://new.url/')
        #self.assertEquals(self.user1.gender, 'female')
        #self.assertEquals(self.user1.image_url, 'http://new.image.url/')

    #def test_socialprofile_form_clean_desc(self):
        #"""Test Form Clean"""
        #LOGGER.debug("Test socialprofile form clean desc")
        #data = model_to_dict(self.user1)
        #data['description'] = '<a href="http://bad.url">Bad Link</a>'
        #form = SocialProfileForm(data=data, instance=self.user1)
        #self.assertTrue(form.is_valid())
        #form.save()
        #self.assertEquals(self.user1.description, 'Bad Link')


# class UserFormTestCase(TestCase):
    # """Tests for  User Form"""

    # def setUp(self):
        # """Set up common assets for tests"""
        # LOGGER.debug("UserForm Tests setUp")
        # self.user1 = User.objects.create_user('user1', 'user1@user1.com', 'user1password')

    # def test_user_form_create(self):
        # LOGGER.debug("Test user form create")
        # data = {
            # 'username': 'user2',
            # 'password': 'user2password',
            # 'email': 'user@user2.com',
            # 'first_name': 'user',
            # 'last_name': '2',
            # 'last_login': '2012-09-04 06:00',
            # 'date_joined': '2012-09-04 06:00',
            # 'manually_edited': False
        # }
        # form = UserForm(data)
        # self.assertTrue(form.is_valid())
        # form.save()
        # user2 = User.objects.get(username='user2')
        # self.assertEquals(user2.username, 'user2')

    # def test_user_form_view(self):
        # """Test editing user profile data through form in isolation"""
        # LOGGER.debug("Test user edit form")
        # form = UserForm(instance=self.user1)
        # form_html = form.as_p()
        # LOGGER.debug(form_html)
        # self.assertInHTML('<input id="id_username" maxlength="30" name="username" type="text" value="user1" />', form_html)
        # self.assertInHTML('<input id="id_first_name" maxlength="30" name="first_name" type="text" />', form_html)
        # self.assertInHTML('<input id="id_email" maxlength="75" name="email" type="email" value="user1@user1.com" />', form_html)
        # self.assertInHTML('<input id="id_last_name" maxlength="30" name="last_name" type="text" />', form_html)
        # self.assertNotIn('<input id="id_is_staff" name="is_staff" type="checkbox" />', form_html)
        # self.assertNotIn('<input checked="checked" id="id_is_active" name="is_active" type="checkbox" />', form_html)

    # def test_user_form_dupe_username(self):
        # LOGGER.debug("Test user form update")
        # data = {
            # 'username': 'user1',
            # 'password': 'user2password',
            # 'email': 'user@user2.com',
            # 'first_name': 'user',
            # 'last_name': '2',
            # 'last_login': '2012-09-04 06:00',
            # 'date_joined': '2012-09-04 06:00',
            # 'manually_edited': False
        # }
        # form = UserForm(data)
        # self.assertIn('already exists', form.errors['username'][0])

    # def test_user_form_update(self):
        # LOGGER.debug("Test user form create")
        # data = {
            # 'username': 'user1',
            # 'first_name': 'user',
            # 'last_name': 'Two',
            # 'last_login': '2012-09-04 06:00',
            # 'date_joined': '2012-09-04 06:00',
            # 'manually_edited': False
        # }
        # form = UserForm(data, instance=self.user1)
        # self.assertTrue(form.is_valid())
        # form.save()
        # self.assertEquals(self.user1.last_name, 'Two')


SITE_ID = 1

# Social Profile
### Custom Social Profile User
AUTH_USER_MODEL = "socialprofile.SocialProfile"
SOCIAL_AUTH_GOOGLE_OAUTH_SCOPE = [
    'https://www.googleapis.com/auth/drive',
    'https://www.googleapis.com/auth/userinfo.profile'
]

SOCIAL_AUTH_PIPELINE = (
    'social.pipeline.social_auth.social_details',
    'social.pipeline.social_auth.social_uid',
    'social.pipeline.social_auth.auth_allowed',
    'social.pipeline.social_auth.social_user',
    'social.pipeline.user.get_username',
    'social.pipeline.mail.mail_validation',
    'social.pipeline.user.create_user',
    'social.pipeline.social_auth.associate_user',
    'social.pipeline.debug.debug',
    'social.pipeline.social_auth.load_extra_data',
    'social.pipeline.user.user_details',
    'socialprofile.pipeline.socialprofile_extra_values',
)

SOCIAL_AUTH_LOGIN_REDIRECT_URL = '/'
SOCIAL_AUTH_NEW_USER_REDIRECT_URL = '/'
SOCIAL_AUTH_NEW_ASSOCIATION_REDIRECT_URL = '/select/'
DEFAULT_RETURNTO_PATH = '/select/'

# Core Authentication Settings
LOGIN_URL = '/select/'
LOGIN_REDIRECT_URL = '/'
LOGIN_ERROR_URL = '/select/'

SESSION_SERIALIZER = 'django.contrib.sessions.serializers.PickleSerializer'

AUTHENTICATION_BACKENDS = (
    # 'django.contrib.auth.backends.ModelBackend',  # Comment if you want DISABLE Login Form (Password)
    'social.backends.amazon.AmazonOAuth2',
    'social.backends.angel.AngelOAuth2',
    'social.backends.aol.AOLOpenId',
    'social.backends.appsfuel.AppsfuelOAuth2',
    'social.backends.beats.BeatsOAuth2',
    'social.backends.behance.BehanceOAuth2',
    'social.backends.belgiumeid.BelgiumEIDOpenId',
    'social.backends.bitbucket.BitbucketOAuth',
    'social.backends.box.BoxOAuth2',
    'social.backends.clef.ClefOAuth2',
    'social.backends.coinbase.CoinbaseOAuth2',
    # 'social.backends.coursera.CourseraOAuth2',
    'social.backends.dailymotion.DailymotionOAuth2',
    'social.backends.disqus.DisqusOAuth2',
    'social.backends.douban.DoubanOAuth2',
    # 'social.backends.dropbox.DropboxOAuth',
    'social.backends.dropbox.DropboxOAuth2',
    # 'social.backends.eveonline.EVEOnlineOAuth2',
    'social.backends.evernote.EvernoteSandboxOAuth',
    'social.backends.facebook.FacebookAppOAuth2',
    'social.backends.facebook.FacebookOAuth2',
    'social.backends.fedora.FedoraOpenId',
    'social.backends.fitbit.FitbitOAuth',
    'social.backends.flickr.FlickrOAuth',
    'social.backends.foursquare.FoursquareOAuth2',
    'social.backends.github.GithubOAuth2',
    # 'social.backends.google.GoogleOAuth',
    'social.backends.google.GoogleOAuth2',
    # 'social.backends.google.GoogleOpenId',
    # 'social.backends.google.GooglePlusAuth',
    # 'social.backends.google.GoogleOpenIdConnect',
    'social.backends.instagram.InstagramOAuth2',
    'social.backends.jawbone.JawboneOAuth2',
    'social.backends.kakao.KakaoOAuth2',
    'social.backends.linkedin.LinkedinOAuth',
    'social.backends.linkedin.LinkedinOAuth2',
    'social.backends.live.LiveOAuth2',
    'social.backends.livejournal.LiveJournalOpenId',
    'social.backends.mailru.MailruOAuth2',
    'social.backends.mendeley.MendeleyOAuth',
    'social.backends.mendeley.MendeleyOAuth2',
    # 'social.backends.mineid.MineIDOAuth2',
    'social.backends.mixcloud.MixcloudOAuth2',
    # 'social.backends.nationbuilder.NationBuilderOAuth2',
    'social.backends.odnoklassniki.OdnoklassnikiOAuth2',
    'social.backends.open_id.OpenIdAuth',
    'social.backends.openstreetmap.OpenStreetMapOAuth',
    'social.backends.persona.PersonaAuth',
    'social.backends.podio.PodioOAuth2',
    'social.backends.rdio.RdioOAuth1',
    'social.backends.rdio.RdioOAuth2',
    'social.backends.readability.ReadabilityOAuth',
    'social.backends.reddit.RedditOAuth2',
    'social.backends.runkeeper.RunKeeperOAuth2',
    'social.backends.skyrock.SkyrockOAuth',
    'social.backends.soundcloud.SoundcloudOAuth2',
    'social.backends.spotify.SpotifyOAuth2',
    'social.backends.stackoverflow.StackoverflowOAuth2',
    'social.backends.steam.SteamOpenId',
    'social.backends.stocktwits.StocktwitsOAuth2',
    'social.backends.stripe.StripeOAuth2',
    'social.backends.suse.OpenSUSEOpenId',
    'social.backends.thisismyjam.ThisIsMyJamOAuth1',
    'social.backends.trello.TrelloOAuth',
    'social.backends.tripit.TripItOAuth',
    'social.backends.tumblr.TumblrOAuth',
    'social.backends.twilio.TwilioAuth',
    'social.backends.twitter.TwitterOAuth',
    'social.backends.vk.VKOAuth2',
    'social.backends.weibo.WeiboOAuth2',
    # 'social.backends.wunderlist.WunderlistOAuth2',
    'social.backends.xing.XingOAuth',
    'social.backends.yahoo.YahooOAuth',
    'social.backends.yahoo.YahooOpenId',
    'social.backends.yammer.YammerOAuth2',
    'social.backends.yandex.YandexOAuth2',
    'social.backends.vimeo.VimeoOAuth1',
    'social.backends.lastfm.LastFmAuth',
    'social.backends.moves.MovesOAuth2',
    # 'social.backends.vend.VendOAuth2',
    'social.backends.email.EmailAuth',
    'social.backends.username.UsernameAuth',
)

SECRET_KEY = 'fake-key'
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'tests.db',
        'SUPPORTS_TRANSACTIONS': 'false',
    }
}
ROOT_URLCONF = 'socialprofile.urls'
INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.sites',
    'django.contrib.staticfiles',
    'django_errors',
    'social.apps.django_app.default',
    'socialprofile'
]


"""Django Views for the socialprofile module"""

# pylint: disable=R0901,R0904

from django.conf import settings
from django.contrib.auth import REDIRECT_FIELD_NAME
from django.core.urlresolvers import reverse_lazy
from django.shortcuts import get_object_or_404, redirect
from django.contrib import messages
from django.contrib.auth.decorators import login_required
from django.contrib.auth import logout as auth_logout, login
from django.http import Http404, HttpResponseRedirect
from django.views.generic import TemplateView, FormView, UpdateView, DeleteView, View
from django.views.generic.base import TemplateResponseMixin, ContextMixin
from django.forms.models import model_to_dict
from django.utils.translation import ugettext_lazy as _


from decorators import render_to
from models import SocialProfile
from forms import SocialProfileForm

from social_core.backends.google import GooglePlusAuth
from social_core.backends.utils import load_backends
from social_django.utils import load_backend, psa

import logging

LOGGER = logging.getLogger(name='socialprofile')

DEFAULT_RETURNTO_PATH = getattr(settings, 'DEFAULT_RETURNTO_PATH', '/')

def logout(request):
    """Logs out user"""
    auth_logout(request)
    return redirect('/')

def context(**extra):
    return dict({
        'plus_id': getattr(settings, 'SOCIAL_AUTH_GOOGLE_PLUS_KEY', None),
        'plus_scope': ' '.join(GooglePlusAuth.DEFAULT_SCOPE),
        'available_backends': load_backends(settings.AUTHENTICATION_BACKENDS)
    }, **extra)

@render_to('socialprofile/sp_account_select.html')
def home(request):
    """Home view, displays login mechanism"""
    if request.user.is_authenticated():
        return redirect('done')
    return context()

@login_required
@render_to('socialprofile/sp_account_select.html')
def done(request):
    """Login complete view, displays user data"""
    if request.user.is_authenticated():
         return context()
    return redirect('sp_select_page')

@psa('social:complete')
def ajax_auth(request, backend):
    if isinstance(request.backend, BaseOAuth1):
        token = {
            'oauth_token': request.REQUEST.get('access_token'),
            'oauth_token_secret': request.REQUEST.get('access_token_secret'),
        }
    elif isinstance(request.backend, BaseOAuth2):
        token = request.REQUEST.get('access_token')
    else:
        raise HttpResponseBadRequest('Wrong backend type')
    user = request.backend.do_auth(token, ajax=True)
    login(request, user)
    data = {'id': user.id, 'username': user.username}
    return HttpResponse(json.dumps(data), mimetype='application/json')	

class SelectAuthView(TemplateView):
    """
    Lets users choose how they want to request access.

    url: /select
    """
    template_name = 'socialprofile/sp_account_select.html'

    def get_context_data(self, **kwargs):
        """Ensure that 'next' gets passed along"""
        LOGGER.debug('socialprofile.views.SelectAuthView.get_context_data')

        next_url = self.request.GET.get(REDIRECT_FIELD_NAME, DEFAULT_RETURNTO_PATH)

        context = super(SelectAuthView, self).get_context_data(**kwargs)
        context['next_param'] = REDIRECT_FIELD_NAME
        context['next_url'] = next_url
        context['plus_id'] = getattr(settings, 'SOCIAL_AUTH_GOOGLE_PLUS_KEY', None)
        context['plus_scope'] = ' '.join(GooglePlusAuth.DEFAULT_SCOPE)
        context['available_backends'] = load_backends(settings.AUTHENTICATION_BACKENDS)
        return context


class SocialProfileView(TemplateView):
    """
    Profile View Page

    url: /profile/view
    """
    template_name = 'socialprofile/sp_profile_view.html'

    http_method_names = {'get'}

    def get_context_data(self, **kwargs):
        """Load up the default data to show in the display form."""
        username = self.kwargs.get('username')
        if username:
			try:
				user = get_object_or_404(SocialProfile, username=username)
			except Exception as e: 
				try:
					user = get_object_or_404(SocialProfile, pk=username)
				except Exception as e: 
					user = self.request.user
        elif self.request.user.is_authenticated():
            user = self.request.user
        else:
            raise Http404  # Case where user gets to this view anonymously for non-existent user
        return {'user': user}

class SocialProfileEditView(SocialProfileView):
    """
    Profile Editing View

    url: /profile/edit
    """

    template_name = 'socialprofile/sp_profile_edit.html'

    http_method_names = {'get', 'post'}

    def post(self, request, *args, **kwargs):
        # user_form = UserForm(request.POST, instance=request.user)
        return_to = self.request.GET.get('returnTo', DEFAULT_RETURNTO_PATH)
        sp_form = SocialProfileForm(request.POST, instance=request.user)
        sp_form.initial['returnTo'] = return_to

        # if user_form.is_valid() & sp_form.is_valid():
        if sp_form.is_valid():
            try:
               # user_form.save()
               sp_form.save()
               messages.add_message(self.request, messages.INFO, _('Your profile has been updated.'))
               return HttpResponseRedirect(sp_form.cleaned_data.get('returnTo', DEFAULT_RETURNTO_PATH))
            except Exception as e:
               messages.add_message(self.request, messages.INFO, _('ERROR: Your profile has NOT been updated! ['+str(e)+']'))
               return self.render_to_response({'sp_form': sp_form})
        else:
            messages.add_message(self.request, messages.INFO, _('Your profile has NOT been updated.'))
            return self.render_to_response({'sp_form': sp_form})


class DeleteSocialProfileView(DeleteView):
    """
    Account Delete Confirm Modal View

    url: /delete
    """

    success_url = reverse_lazy('sp_logout_page')

    template_name = "socialprofile/sp_delete_account_modal.html"

    model = SocialProfile

    def get_object(self, queryset=None):
        """Get the object that we are going to delete"""
        return self.request.user



"""Custom Widget to enable use of HTML5 Form element types"""
from django.forms.widgets import TextInput, DateInput, DateTimeInput, TimeInput


class H5EmailInput(TextInput):
    """HTML5 Email Input Type"""
    input_type = 'email'


class H5NumberInput(TextInput):
    """HTML5 Number Input Type"""
    input_type = 'number'


class H5TelephoneInput(TextInput):
    """HTML5 Telephone Number Input Type"""
    input_type = 'tel'


class H5DateInput(DateInput):
    """HTML5 Date Input Type"""
    input_type = 'date'


class H5DateTimeInput(DateTimeInput):
    """HTML5 DateTime Input Type"""
    input_type = 'datetime'


class H5TimeInput(TimeInput):
    """HTML5 Time Input Type"""
    input_type = 'time'



"""Django Admin Site configuration for socialprofiles"""

# pylint: disable=R0901,R0904

from django.contrib import admin
from socialprofile.models import SocialProfile
from image_cropping.admin import ImageCroppingMixin

class CustomUserAdmin(ImageCroppingMixin, admin.ModelAdmin):
    """Sets up the custom user admin display"""
    list_display = ('username', 'email', 'gender', 'first_name', 'last_name', 'is_staff', 'is_active', 'manually_edited','visible')

admin.site.register(SocialProfile, CustomUserAdmin)



from functools import wraps

from django.template import RequestContext
from django.shortcuts import render_to_response


def render_to(tpl):
    def decorator(func):
        @wraps(func)
        def wrapper(request, *args, **kwargs):
            out = func(request, *args, **kwargs)
            if isinstance(out, dict):
                out = render_to_response(tpl, out, RequestContext(request))
            return out
        return wrapper
    return decorator



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-08 00:39
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models
import image_cropping.fields
import socialprofile.models


class Migration(migrations.Migration):

    initial = True

    operations = [
        migrations.CreateModel(
            name='SocialProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('username', models.CharField(error_messages={b'unique': 'A user with that username already exists.'}, help_text='Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=30, unique=True, validators=[django.core.validators.RegexValidator(b'^[\\w.@+-]+$', 'Enter a valid username. This value may contain only letters, numbers and @/./+/-/_ characters.')], verbose_name='username')),
                ('first_name', models.CharField(blank=True, max_length=30, verbose_name='First Name')),
                ('last_name', models.CharField(blank=True, max_length=30, verbose_name='Last Name')),
                ('email', models.EmailField(blank=True, max_length=254, verbose_name='Email Address')),
                ('is_staff', models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
                ('gender', models.CharField(blank=True, choices=[('male', 'Male'), ('female', 'Female'), ('other', 'Other'), (b'', b'')], max_length=10, verbose_name='Gender')),
                ('url', models.URLField(blank=True, help_text='Where can we find out more about you?', max_length=500, verbose_name='Homepage')),
                ('image_url', models.URLField(blank=True, max_length=500, verbose_name='Avatar Picture')),
                ('image', image_cropping.fields.ImageCropField(blank=True, upload_to=b'user/')),
                ('cropping', image_cropping.fields.ImageRatioField(b'image', '120x100', adapt_rotation=False, allow_fullsize=True, free_crop=False, help_text=None, hide_image_field=False, size_warning=False, verbose_name='cropping')),
                ('cropping_free', image_cropping.fields.ImageRatioField(b'image', '300x300', adapt_rotation=False, allow_fullsize=False, free_crop=True, help_text=None, hide_image_field=False, size_warning=True, verbose_name='cropping free')),
                ('description', models.TextField(blank=True, help_text='Tell us about yourself!', verbose_name='Description')),
                ('manually_edited', models.BooleanField(default=False, verbose_name='Manually Edited')),
                ('date_joined', models.DateTimeField(auto_now_add=True, verbose_name='Date Joined')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Date Updated')),
                ('avatar', models.ImageField(blank=True, null=True, upload_to=b'avatars/')),
                ('sort', socialprofile.models.IntegerRangeField(blank=True, default=1, verbose_name='Sort Order')),
                ('visible', models.BooleanField(default=False, verbose_name='Visible in the Public Pages')),
                ('title', models.CharField(blank=True, max_length=500)),
                ('role', models.CharField(blank=True, max_length=500)),
                ('function_01', models.CharField(blank=True, max_length=200)),
                ('function_02', models.CharField(blank=True, max_length=200)),
                ('function_03', models.CharField(blank=True, max_length=200)),
                ('function_04', models.CharField(blank=True, max_length=200)),
                ('function_05', models.CharField(blank=True, max_length=200)),
                ('function_06', models.CharField(blank=True, max_length=200)),
                ('function_07', models.CharField(blank=True, max_length=200)),
                ('function_08', models.CharField(blank=True, max_length=200)),
                ('function_09', models.CharField(blank=True, max_length=200)),
                ('function_10', models.CharField(blank=True, max_length=200)),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='user_set', related_query_name='user', to='auth.Group', verbose_name='groups')),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions')),
            ],
            options={
                'ordering': ['username'],
                'verbose_name': 'Social Profile',
                'verbose_name_plural': 'Social Profiles',
            },
            managers=[
                ('objects', socialprofile.models.UserManager()),
            ],
        ),
    ]



from setuptools import setup, find_packages

readme = open('README.md').read()

from socialprofile import __version__ as version

setup(
    name="django-sp",
    version=version,
    url='https://github.com/DLRSP/django-sp',
    license='MIT',
    description="Django Custom Social Profile Auth/User",
    author='DLRSP',
    author_email='dlrsp.py@gmail.com',
    packages=find_packages(),
    long_description=readme,
    include_package_data=True,
    zip_safe=False,
    install_requires=['django-jenkins',
                      'django<1.11',
                      'social-auth-app-django',      #<-- Need By Auth Process
                      'django-errors',
                      'easy_thumbnails',		 #<-- Need By Imge Cropping
                      'django-image-cropping',
                      ],
    tests_require=['runtests.py'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ]
)



#"""Unit Tests for the socialprofile module forms"""

## pylint: disable=R0904, C0103

#from django.test import TestCase

#from django.core.exceptions import ObjectDoesNotExist
#from socialprofile.models import SocialProfile
#from social.apps.django_app.default.models import UserSocialAuth
#from socialprofile.forms import SocialProfileForm
#from django.forms.models import model_to_dict
#from socialprofile.pipeline import facebook_extra_values, google_extra_values, socialprofile_extra_values, twitter_extra_values
#from social.backends.google import GoogleOAuth2
#from social.backends.twitter import TwitterOAuth
#from social.backends.facebook import Facebook2OAuth2

#import logging

#LOGGER = logging.getLogger(name='socialprofile.test_forms')


#class SocialProfilePipelineTestCase(TestCase):
    #"""Test Case for Social Profile Pipeline"""

    #def setUp(self):
        #"""Set up common assets for tests"""
        #LOGGER.debug("SocialProfile Pipeline Tests setUp")
        #self.user1 = SocialProfile.objects.create_user('user1', 'user1@user1.com', 'user1password')
        #self.user1.gender = 'other'
        #self.user1.url = 'http://test.com'
        #self.user1.description = 'Test User 1'
        #self.user1.image_url = 'http://www.gravatar.com/avatar/00000000000000000000000000000000?d=mm'
        #self.user1.save()
        ## self.sa1 = UserSocialAuth.objects.create(user=self.user1, provider='google-oauth2', uid='user1@user1.com')

    #def test_socialprofile_pipeline_google(self):
        #"""Test editing executing pipeline methods in isolation for google"""
        #LOGGER.debug("Test socialprofile pipeline Google")
        #backend = GoogleOAuth2()
        #response = {
            #'name': {
                #'familyName': 'User 1',
                #'givenName': 'Test'
            #},
            #'gender': 'other',
            #'image': {'url': 'http://image.url'},
            #'occupation': 'User Description',
            #'url': 'http://test.com'
        #}

        #socialprofile_extra_values(backend, {}, response, '1', self.user1)
        #self.assertEquals(self.user1.description, 'User Description')
        #self.assertEquals(self.user1.gender, 'other')
        #self.assertEquals(self.user1.image_url, 'http://image.url')
        #self.assertEquals(self.user1.url, 'http://test.com')

    #def test_socialprofile_pipeline_facebook(self):
        #"""Test editing executing pipeline methods in isolation for facebook"""
        #LOGGER.debug("Test socialprofile pipeline Facebook")
        #backend = Facebook2OAuth2()
        #response = {
            #'name': {
                #'last_name': 'User 1',
                #'first_name': 'Test'
            #},
            #'gender': 'other',
            #'picture': {'data': {'url': 'http://image.url'}},
            #'link': 'http://test.com'
        #}

        #socialprofile_extra_values(backend, {}, response, '1', self.user1)
        #self.assertEquals(self.user1.gender, 'other')
        #self.assertEquals(self.user1.image_url, 'http://image.url')
        #self.assertEquals(self.user1.url, 'http://test.com')

    #def test_socialprofile_pipeline_twitter(self):
        #"""Test editing executing pipeline methods in isolation for twitter"""
        #LOGGER.debug("Test socialprofile pipeline Twitter")
        #backend = TwitterOAuth()
        #response = {
            #'name': {
                #'last_name': 'User 1',
                #'first_name': 'Test'
            #},
            #'gender': 'other',
            #'profile_image_url_https': 'http://image.url',
            #'description': 'User Description',
            #'url': 'http://test.com'
        #}

        #socialprofile_extra_values(backend, {}, response, '1', self.user1)
        #self.assertEquals(self.user1.description, 'User Description')
        #self.assertEquals(self.user1.gender, 'other')
        #self.assertEquals(self.user1.image_url, 'http://image.url')
        #self.assertEquals(self.user1.url, 'http://test.com')